@@ -3,12 +3,10 @@ use warnings;
 
 package Test::Tester::Delegate;
 
-our $VERSION = '1.302125';
+our $VERSION = '1.302211';
 
 use Scalar::Util();
 
-use vars '$AUTOLOAD';
-
 sub new
 {
 	my $pkg = shift;
@@ -21,7 +19,7 @@ sub new
 
 sub AUTOLOAD
 {
-	my ($sub) = $AUTOLOAD =~ /.*::(.*?)$/;
+	my ($sub) = our $AUTOLOAD =~ /.*::(.*?)$/;
 
 	return if $sub eq "DESTROY";
 
